==> matrix_sdk-0.1.9.tar.gz: lib/src/event/room/message_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/identifier.dart';

abstract class MessageEvent extends RoomEvent {
  static const String type = 'm.room.message';

  @override
  final String _type = type;

  String get _messageType;

  MessageEvent(EventId id, RoomId roomId, UserId sender, DateTime time)
      : super(id, roomId, sender, time);

  factory MessageEvent.fromJson(
      EventId id, RoomId roomId, UserId sender,
      DateTime time, Map<String, dynamic> json) {

    var msgtype = json['content']['msgtype'];

    switch (msgtype) {
      case TextMessageEvent.type:
      default:
        var body = json['content']['body'];
        return TextMessageEvent(body, id, roomId, sender, time);
    }
  }

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'content': {
        'msgtype': _messageType
      }
    });
}

class TextMessageEvent extends MessageEvent {
  static const String type = 'm.text';

  @override
  final String _messageType = type;

  final String body;

  TextMessageEvent(this.body, EventId id, RoomId roomId, UserId sender, DateTime time)
      : super(id, roomId, sender, time);

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..['content']
      .addAll({
        'body': body
      });
}

==> matrix_sdk-0.2.4.tar.gz: lib/src/event/room/message_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/user.dart';

abstract class MessageEvent extends RoomEvent {
  static const String type = 'm.room.message';

  @override
  final String matrixType = type;

  String get _messageType;

  MessageEvent(EventId id, Room room, User sender, DateTime time)
      : super(id, room, sender, time);

  factory MessageEvent.fromJson(
      EventId id, Room room, User sender,
      DateTime time, Map<String, dynamic> json) {

    var msgtype = json['content']['msgtype'];

    switch (msgtype) {
      case TextMessageEvent.type:
      default:
        var body = json['content']['body'];
        return TextMessageEvent(body, id, room, sender, time);
    }
  }

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'content': {
        'msgtype': _messageType
      }
    });
}

class TextMessageEvent extends MessageEvent {
  static const String type = 'm.text';

  @override
  final String _messageType = type;

  final String body;

  TextMessageEvent(this.body, EventId id, Room room, User sender, DateTime time)
      : super(id, room, sender, time);

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..['content']
      .addAll({
        'body': body
      });
}
